@@ -61,7 +61,7 @@ def apply_life_rule(old, new):
 
 
 def randomize(output, fraction=0.33):
-    """ Fill 'fraction' out of all the cells. """
+    """Fill 'fraction' out of all the cells."""
     for i in range(output.height * output.width):
         output[i] = random.random() < fraction
 
@@ -106,10 +106,10 @@ b2 = displayio.Bitmap(display.width // SCALE, display.height // SCALE, 2)
 palette = displayio.Palette(2)
 tg1 = displayio.TileGrid(b1, pixel_shader=palette)
 tg2 = displayio.TileGrid(b2, pixel_shader=palette)
-g1 = displayio.Group(max_size=3, scale=SCALE)
+g1 = displayio.Group(scale=SCALE)
 g1.append(tg1)
 display.show(g1)
-g2 = displayio.Group(max_size=3, scale=SCALE)
+g2 = displayio.Group(scale=SCALE)
 g2.append(tg2)
 
 # First time, show the Conway tribute
